@@ -373,10 +373,79 @@ def create_levermann(dx,df,gspc,start,financial_flag=False):
     """
     dxx2["levermann_score"]=dxx2["l_pio1_4"]+dxx2["l1_equity_ratio"]+dxx2["l2_ebit_margin"]+dxx2["l3_equity_ratio"]+dxx2["l4_pe_5years"]+dxx2["l5_pe_forward"]+dxx2["l9_perf_6m"]+dxx2["l10_perf_1y"]+dxx2["l11_momentum"]+dxx2["l12_reversal"]+dxx2["l13_growth"]
     
+    """
+    High-Growth-Score
+    """
+    hgi_drops=[]
+    #EV = Market Capitaliztion + (longTermDebt + shortTermDebt) – cashAndEquivalents 
+    dxx2["market_cap_orig"]=dxx2["shares"]*dxx2["Adjusted_Close"]
+    dxx2["EV"] = dxx2["market_cap_orig"] + dxx2["longTermDebt"] + dxx2["shortTermDebt"] - dxx2["cashAndEquivalents"]
+    dxx2["EV_per_sales"] = dxx2["EV"] / dxx2["totalRevenue"]
+    hgi_drops.extend(["market_cap_orig","EV","EV_per_sales"])
+    """
+    gp_ttm
+    rule_of_40
+    debt_ratio
+    revenue_growth_ttm
+    PEG (TTM) = KGV / (Gewinn letzte 4 Quartale / Gewinn vorherige 4 Quartale)
+    """
+    dxx2["pe_ttm"]=dxx2["Adjusted_Close"]/dxx2["earningsEstimateAvg"]
+    dxx2["netIncome_delta"]=dxx2["netIncome_ttm"] / dxx2["netIncome_ttm"].shift(252)
+    dxx2["peg_ttm"] = dxx2["pe_ttm"] / dxx2["netIncome_delta"]
+    hgi_drops.extend(["pettm","peg_ttm","netIncome_delta"])
+    """
+    Kriterium 	3 Punkte 	2 Punkte 	1 Punkt
+    1. EV/Sales 	≤ 8 	> 8 und ≤ 10 	> 10 und ≤ 12
+    2. Gross Margin (TTM) 	≥ 75% 	< 75% und ≥ 65% 	< 65% und ≥ 50%
+    3. Rule of 40 (TTM) 	≥ 50% 	< 50% und ≥ 45% 	< 45% und ≥ 40%
+    4. Umsatzwachstum (TTM) 	≥ 40% 	< 40% und ≥ 30% 	< 30% und ≥ 20%
+    5. Verschuldungsgrad 	≤ 0,5 	> 0,5 und ≤ 1 	> 1 und ≤ 1,5
+    6. PEG (TTM) 	> 0 und < 1 	≥ 1 und < 2 	≥ 2 und < 4
+    """
+    dxx2["hgi_ev_sales"]=0
+    dxx2.loc[(dxx2["EV_per_sales"] > 0.1) & (dxx2["EV_per_sales"] <= 0.12),"hgi_ev_sales"]=1
+    dxx2.loc[(dxx2["EV_per_sales"] > 0.08) & (dxx2["EV_per_sales"] <= 0.1),"hgi_ev_sales"]=2
+    dxx2.loc[ (dxx2["EV_per_sales"] <= 0.08),"hgi_ev_sales"]=3
+    hgi_drops.extend(["hgi_ev_sales","EV_per_sales"])
+
+
+    dxx2["hgi_gp_ttm"]=0
+    dxx2.loc[(dxx2["gp_ttm"] > 0.5 ) & (dxx2["gp_ttm"] <= 0.65 ) , "hgi_gp_ttm"] = 1
+    dxx2.loc[(dxx2["gp_ttm"] > 0.65 ) & (dxx2["gp_ttm"] <= 0.75 ) , "hgi_gp_ttm"] = 2
+    dxx2.loc[(dxx2["gp_ttm"] > 0.75 )  , "hgi_gp_ttm"] = 3
+    hgi_drops.extend(["hgi_gp_ttm","gp_ttm"])
+
+    dxx2["hgi_r40"]=0
+    dxx2.loc[(dxx2["rule_of_40"] > 0.4 ) & (dxx2["rule_of_40"] <= 0.45 ) , "hgi_r40"] = 1
+    dxx2.loc[(dxx2["rule_of_40"] > 0.45 ) & (dxx2["rule_of_40"] <= 0.5 ) , "hgi_r40"] = 2
+    dxx2.loc[(dxx2["rule_of_40"] > 0.5 ) , "hgi_r40"] = 3
+    hgi_drops.extend(["hgi_r40","rule_of_40"])
+    dxx2["hgi_revenue_growth_ttm"]=0
+    dxx2.loc[(dxx2["revenue_growth_ttm"] > 0.2 ) & (dxx2["revenue_growth_ttm"] <= 0.3 ) , "hgi_revenue_growth_ttm"] = 1
+    dxx2.loc[(dxx2["revenue_growth_ttm"] > 0.3 ) & (dxx2["revenue_growth_ttm"] <= 0.4 ) , "hgi_revenue_growth_ttm"] = 2
+    dxx2.loc[(dxx2["revenue_growth_ttm"] > 0.4 ) , "hgi_revenue_growth_ttm"] = 3
+    hgi_drops.extend(["hgi_revenue_growth_ttm","revenue_growth_ttm"])
+    dxx2["hgi_debt_ratio"]=0
+    dxx2.loc[(dxx2["debt_ratio"] > 1 ) & (dxx2["debt_ratio"] <= 1.5 ) , "hgi_debt_ratio"] = 1
+    dxx2.loc[(dxx2["debt_ratio"] > 0.5 ) & (dxx2["debt_ratio"] <= 1 ) , "hgi_debt_ratio"] = 2
+    dxx2.loc[(dxx2["debt_ratio"] <= 0.5 ) , "hgi_debt_ratio"] = 3
+    hgi_drops.extend(["hgi_debt_ratio","debt_ratio"])
+    dxx2["hgi_peg_ttm"]=0
+    dxx2.loc[(dxx2["peg_ttm"] >  2) & (dxx2["peg_ttm"] <= 4 ) , "hgi_peg_ttm"] = 1
+    dxx2.loc[(dxx2["peg_ttm"] > 1 ) & (dxx2["peg_ttm"] <= 2 ) , "hgi_peg_ttm"] = 2
+    dxx2.loc[(dxx2["peg_ttm"] <= 1 ) , "peg_ttm"] = 3
+    hgi_drops.extend(["hgi_peg_ttm","peg_ttm"])
+
+    dxx2["hgi_score"] = dxx2["hgi_ev_sales"] + dxx2["hgi_gp_ttm"] +dxx2["hgi_r40"]+dxx2["hgi_revenue_growth_ttm"]+dxx2["hgi_debt_ratio"]+dxx2["hgi_peg_ttm"]
+    dxx2.drop(columns=hgi_drops,inplace=True)
+
+
+    
+
     #dxx2.to_parquet("data/eod/levermann.parquet")
     
     return dxx2
-
+    
 class Resolver():
     def __init__(self,path,rebuild=False,extension="json"):
         self.path=path
